@@ -789,7 +789,7 @@ class DocumentLiteralSOAPInterface(BaseInterface):
 
 	@staticmethod
 	def _interface_name():
-		return 'soapdocumentliteral'
+		return 'soap'
 
 	@staticmethod
 	def _accept_basetype(typ):
